(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{24:function(t,n,e){"use strict";e.r(n);var c=e(5),o=e.n(c),r=e(15),a=e.n(r),i=e(0),s=e(1),u=e(2),p=e(3),l=e(12),m=function(t){Object(u.a)(e,t);var n=Object(p.a)(e);function e(){var t;Object(i.a)(this,e);for(var c=arguments.length,o=new Array(c),r=0;r<c;r++)o[r]=arguments[r];return(t=n.call.apply(n,[this].concat(o))).myFunction=function(){var n=t.props.args.message,e=window.confirm(n);l.a.setComponentValue(e?"Yes":"No")},t.render=function(){return null},t}return Object(s.a)(e,[{key:"componentDidMount",value:function(){this.myFunction()}}]),e}(l.b),b=Object(l.c)(m),j=e(13);a.a.render(Object(j.jsx)(o.a.StrictMode,{children:Object(j.jsx)(b,{})}),document.getElementById("root"))}},[[24,1,2]]]);
//# sourceMappingURL=main.6500dfab.chunk.js.map